#
# spec file for package python-gnocchiclient
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-gnocchiclient
Version:        7.0.5
Release:        1.7
Summary:        Python API and CLI for OpenStack Gnocchi
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://github.com/openstack/python-gnocchiclient
Source0:        https://pypi.io/packages/source/g/gnocchiclient/gnocchiclient-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pbr}
BuildRequires:  python-rpm-macros
Requires:       python-cliff >= 2.10.0
Requires:       python-debtcollector
Requires:       python-futurist
Requires:       python-iso8601
Requires:       python-keystoneauth1 >= 2.0.0
Requires:       python-monotonic
Requires:       python-osc-lib >= 1.7.0
Requires:       python-pbr >= 2.0.0
Requires:       python-python-dateutil
Requires:       python-six >= 1.9.0
Requires:       python-ujson
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%python_subpackages

%description
This is a client library for Gnocchi built on the Gnocchi API. It
provides a Python API (the gnocchiclient module) and a command-line tool.

%prep
%autosetup -n gnocchiclient-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/gnocchi

%post
%python_install_alternative gnocchi

%postun
%python_uninstall_alternative gnocchi

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/gnocchi
%{python_sitelib}/gnocchiclient
%{python_sitelib}/*.egg-info

%changelog
* Thu Feb 28 2019 tbechtold@suse.com
- update to 7.0.5:
  * pep8: fix RST304 errors
  * pep8: enable logging format checks
  * Remove hacking dependency for pep8
  * tests: remove testtools and fixtures dependencies
  * exeptions: fix matching when description is a dict
  * Support Python 3.7 instead of 3.5
  * shell: fix OS\_AUTH\_TYPE workaround
  * Always use proxy method to get client
  * Update mergify configuration
  * Update mergify configuration
  * Enable mergify
  * Fix regression with exoic timestamp
  * exceptions: remove MutipleMeaningException class
  * Avoid using openstack-doc-tools
  * tests: adapt status tests output
  * status: add metricd processor report
* Mon Mar  5 2018 tbechtold@suse.com
  update to version 7.0.1
  * Install pifpaf with gnocchi flavor
  * Fix osc client
  * Remove wrong comment
  * Fix doc link
  * Remove client side query parsing
  * Add missing requirement
  * metric: add support for metric pagination by default
  * Add Travis configuration for GitHub
  * Add badges to README
  * doc: update config and builder
  * Remove .gitreview
  * Use Python 3 for docs and pep8 test target
  * Add ResourceTypeAlreadyExists exception
  * Make build_pagination_options return a dict
  * Remove ugly Travis/Docker workaround
  * metric_cli: convert datetime before returning
  * Only run tests on pull requests
  * Drop oslo.utils
  * Improve authentication documentation
  * Use pretty_tox to run tests
  * Remove __version__ from gnocchiclient module
  * Pass explicit kwargs to metric.create
  * Add update archive policy rule in osc
  * Don't require osc_lib
  * Remove outdated mention of OpenStack
  * Use cumulated runtime to compute op/s
  * tests: move to pytest
  * tests: fix start/stop timestamp not being in UTC
  * Remove doc8 from gnocchi.xyz
  * metric: reduce output on metric show
  * Fix exception name for keystoneauth1
  * Remove useless comment
  * Fix Gnocchi tarball URL in tests
  * Update mailmap entries for sileht and gord
  * remove noauth from docs
  * Set the Cliff namespace
  * fix use of unicode breaking python 2 help output
  * Add archive-policy-rule update
  * Remove deprecated compatibility session options in client
  * tests: fix tests not specifying UTC
  * add aggregates API
  * Use Travis to upload releases
  * Replace "openstack metric metric..." commands
  * tests: use a fixture to fake TZ in environ
  * Drop oslo.serialization
  * resource-type: fixed attributes specific options of resource-type
  * Replace oslotest by testtools
  * Add "server version" client
  * shell: workaround missing OS_AUTH_TYPE when using Keystone auth
  * travis: allow Docker to write in home directory
  * metric: parse ISO8601 as datetime Python objects
  * benchmark: generate just enough point for a batch
  * travis: pull docker gnocchi-ci-tools docker image rather than building
  * Translate keystoneauth1 exceptions in gnocchiclient exceptions
  * Run doc-gnocchi.xyz job in Travis
  * tests: use a random metric name
  * benchmark: print the number of measures per request on show
  * Clear .gitignore
  * Remove oslopshinx
  * Remove outdated tox-travis configuration
  * Remove tempest dependency
  * Show and parse timestamps in local timezone by default
  * Switch testing to Docker
  * Add missing dependency on pyparsing
  * Move doc8 into pep8 target
  * fix benchmark stopwatch
  * aggregates: new output parsing
- Convert to singlespec
* Thu Sep 21 2017 dmueller@suse.com
- drop runtime dependency on openstack-doc-tools
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 3.1.1
  - Fix data display when listing resources
  - Use new keystoneauth1 helper
  - shell: make client works with default Gnocchi installation
  - Stop always encoding resource
  - doc: Add authentication examples
  - Trivial: remove support for py34
  - docs: Add all commands help
  - allow to pass session and adapter options
  - add note when using OS_AUTH_TYPE
  - Remove pbr cap
  - exceptions: make sure resource type not found is checked before resource not found
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.8.2:
  - Add "batch delete resource client"
  - Remove unused method
  - [doc] Note lack of constraints is a choice
  - Add support for basic authentication
  - support resample option
  - Remove no more usefull help
  - Use proper unicode type for help string
  - Remove non working operator
  - Bump hacking to 0.12
  - Updated coverage configuration file
  - Switch to basic auth in functional tests and fix encoding
  - Add reaggregation function argument to measures aggregation
  - fix 409 exception regex
  - Update .coveragerc after the removal of openstack directory
  - add support for refresh
  - Add ResourceTypeNotFound exception
  - support fill option
  - metric: add support for `--create-metrics' in batch-resources-metrics
  - Handles http error parse of keystone
  - Allow to update resource_type
  - Fix a has been deprecated api
  - osc: Pass interface and region to gnocchi client
  - enable pagination for metric list
  - resource: Set correct attribute type
  - Delete the useless code
  - auth: fix header type
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
* Mon Sep  5 2016 tbechtold@suse.com
  update to version 2.5.0
  * Use osc-lib instead of openstackclient
  * Remove redundant parentheses
  * Fix bad entry points in setup.cfg
  * [Trivial] Remove executable privilege of doc/source/conf.py
  * noauth: fix endpoint envvar
  * doc: use pbr to auto-generate doc
  * Translate resource_id to UUID5 format.
  * Add mailmap entry for sileht
  * exceptions: use lower case everywhere
  * Use pifpaf instead of overtest to run tests
  * Fix gate failures
  * Remove testscenarios dependency
  * doc: some improvements
  * Add granularity argument to measures aggregation
  * Use overtest to run Gnocchi
  * Raise the correct exception on archive policy rule not found
  * Bump hacking to 0.11.0
  * Switch from deprecated tempest-lib to tempest
  * Quote query string when POST is used
  * utils: allow to encode params with list/tuple
  * Remove refernces to queues in the osc client
  * Use extras in setup.cfg for deps
  * fix typos in comment & help string
  * Raise an error when metric name doesn't exists
  * Make the wheel universal
  * Allow to start Gnocchi command with OSC
  * Prepare compatibility with OSC
  * fix test debug
  * Remove i18n support
  * Supported resources list cli support
  * Ensure description exists for HTTP error.
  * Fix a spell typos
  * exceptions: use url from Reponse object
  * Show original_resource_id in resource list cmd
  * Support newer version of MySQL
  * Allow create resource type
  * utils: allow UUID to not have any dash
  * shell: document query parameters
  * Allow to list resource-types
  * utils: switch format function to functional
  * Remove discover test-dependency
  * Allow to show a resource type
  * show and add unit for metric list and create
  * doc: fix typo in shell
  * Use tox to install Gnocchi
  * Trival: Remove unused logging import
  * utils: include 0 values
  * cli: use type kwarg from argparse to parse queries
  * Add granularity argument to measures show
  * resource: show all attributes when requesting detailed history
  * Make utils.dict_to_querystring result predictible
  * [resource] fix custom formatting of metrics
  * shell: disallow abbrev in argparse
  * Clean flake8 ignore
  * search: Ensure we didn't ignore extra chars
  * Fix gnocchi new install deps and func test
  * supplement the type of marker explaination
  * benchmark: allow to wait for all measures to be processed
  * Corrected docstring for create metric
  * Fix delete metric on resource create/update
  * resource: move --delete-metric to update only
  * Add doc building for gnocchi.xyz
  * exceptions: fix typo in class name
  * Delete openstack/common from the exclude list of flake8 in tox
  * Allow to delete a resource type
  * benchmark: minimize client computed time
  * metric: add support for groupby in aggregation
  * Fix docstring in from_response
  * Use overtest to run MySQL
  * remove MANIFEST.in
  * minimise report
  * fix custom formatting of archive policy
  * Add batching to client
  * add support for update archive policy
  * Update the home-page with developer documentation
  * fix benchmark entry points
  * tests: do not use "low" as archive policy name
  * Add support for Python 3.5
  * The search query is mandatory
  * one type error in resource.py
  * tests: Fix option names
  * shell: remove "resource list-types"
- Update _service and switch to upstream spec template
* Fri Mar 18 2016 dmueller@suse.com
- downgrade python-gnocchi to recommends
* Wed Mar  2 2016 dmueller@suse.com
- update to 2.1.0:
  * Allow to set resource type for aggregation
  * Examples in doc should be workable
  * Handle rename from dbsync to upgrade
  * Fixed history parameter having no effect on search
* Thu Jan 21 2016 aplanas@suse.com
- Initial package
